@@ -11,6 +11,7 @@ import pandas as pd
 from pprint import pprint
 from oauth2client.service_account import ServiceAccountCredentials
 import numpy as np
+
 class NumpyEncoder(json.JSONEncoder):
     """ Custom encoder for numpy data types """
     def default(self, obj):
@@ -54,7 +55,12 @@ class EasySpreadsheet():
         
         if sheet_name:
             self._load()
-    
+
+    @property
+    def doc(self):
+        return self._doc
+        
+
     def select(self):
         return self.table
     
@@ -74,8 +80,9 @@ class EasySpreadsheet():
                 cell.value = value
                 cell_list.append(cell)
 
-        self._cloudsheet.clear()
-        self._cloudsheet.update_cells(cell_list)
+        if len(cell_list):
+            self._cloudsheet.update_cells(cell_list, value_input_option='USER_ENTERED')
+        
 
 
     def format(self, start_column, start_index, end_column, end_index, cell_format):
@@ -112,7 +119,7 @@ class EasySpreadsheet():
     def _load(self):
 
         self._cloudsheet = self._doc.worksheet(self._sheet_name)
-        records = self._cloudsheet.get_all_values()
+        records = self._cloudsheet.get_all_values('FORMULA')
         rows = []
         for row in records:
             temp = []
@@ -150,4 +157,4 @@ class EasySpreadsheet():
 
             temp.append(v)
 
-        return temp
+        return temp
\ No newline at end of file
